import static org.junit.Assert.*;

import org.junit.Test;

public class KnapsackTests {

	@Test
	public void testKnapsack() {
		assertEquals(3, Knapsack.solve(new int[] {0,1,2}, new int[] {0,1,2}, 10));
	}

	@Test(expected = IllegalArgumentException.class)
	public void testValuesIsNull() {
		Knapsack.solve(new int[] {0}, null, 0);
	}
	
	@Test(expected = IllegalArgumentException.class)
	public void testWeightsIsNull() {
		Knapsack.solve(new int[] {0}, null, 0);
	}
	
	@Test(expected = IllegalArgumentException.class)
	public void testArraysHaveDifferentLengths() {
		Knapsack.solve(new int[] {0}, new int[]{0,0}, 0);
	}
	
	@Test
	public void testKnapsackBranchCoverage() {
		assertEquals(4, Knapsack.solve(new int[] {1,3,5}, new int[] {1,3,5}, 4));
	}
		
	@Test
	public void testKnapsackFunctionalTests() {
		//empty set of items
		assertEquals(0, Knapsack.solve(new int[0], new int[0], 0));
		
		//one element in the set of items
		assertEquals(0, Knapsack.solve(new int[] {0}, new int[] {0}, 0));		
		assertEquals(0, Knapsack.solve(new int[] {1}, new int[] {1}, 0));		
		assertEquals(1, Knapsack.solve(new int[] {1}, new int[] {1}, 1));
		assertEquals(1, Knapsack.solve(new int[] {1}, new int[] {1}, Integer.MAX_VALUE));		
		assertEquals(0, Knapsack.solve(new int[] {Integer.MAX_VALUE}, new int[] {1}, 0));
		assertEquals(Integer.MAX_VALUE, Knapsack.solve(new int[] {Integer.MAX_VALUE}, new int[] {1}, 1));
		assertEquals(Integer.MAX_VALUE, Knapsack.solve(new int[] {Integer.MAX_VALUE}, new int[] {1}, Integer.MAX_VALUE));

		//more than one elements in the set of items
		assertEquals(0, Knapsack.solve(new int[] {0,0}, new int[] {1,1}, 0));
		assertEquals(0, Knapsack.solve(new int[] {Integer.MAX_VALUE,0}, new int[] {1,1}, 0));
		assertEquals(0, Knapsack.solve(new int[] {0,Integer.MAX_VALUE}, new int[] {1,1}, 0));
		assertEquals(0, Knapsack.solve(new int[] {Integer.MAX_VALUE,Integer.MAX_VALUE}, new int[] {1,1}, 0));
		assertEquals(Integer.MAX_VALUE, Knapsack.solve(new int[] {Integer.MAX_VALUE,0}, new int[] {1,1}, 1));
		assertEquals(Integer.MAX_VALUE, Knapsack.solve(new int[] {0,Integer.MAX_VALUE}, new int[] {1,1}, 1));
		assertEquals(Integer.MAX_VALUE, Knapsack.solve(new int[] {Integer.MAX_VALUE,Integer.MAX_VALUE}, new int[] {1,1}, 1));
		assertEquals(Integer.MAX_VALUE, Knapsack.solve(new int[] {Integer.MAX_VALUE,0}, new int[] {1,1}, Integer.MAX_VALUE));
		assertEquals(Integer.MAX_VALUE, Knapsack.solve(new int[] {0,Integer.MAX_VALUE}, new int[] {1,1}, Integer.MAX_VALUE));		
		
	}

}
